"""
Type annotations for s3transfer.constants module.

Copyright 2025 Vlad Emelianov
"""

KB: int = ...
MB: int = ...
GB: int = ...
ALLOWED_DOWNLOAD_ARGS: list[str] = ...
FULL_OBJECT_CHECKSUM_ARGS: list[str] = ...
USER_AGENT: str = ...
PROCESS_USER_AGENT: str = ...
